#ifndef BBOXMINMAX_H
#define BBOXMINMAX_H

#include <vector>
#include <Vector3D.h>

/// A simple class which encapsulate the max and min corner of a bounding box.
/**
 * The algorithm "Marching Cube" needs a bounding box for computing a set of polygones
 * defining the surface of an F-Rep. RBF needs also this class.
 *
 * This class is defined only by 6 real : min and max values of x, y, and z.
 */
class BBoxMinMax {
public :
  BBoxMinMax (double minx, double miny, double minz,
	      double maxx, double maxy, double maxz);
  
  /// Scale the value of the min and max corner of the box.
  void scale (float coeff);

  inline std::vector<double> getMinMax () const {
    return minMax;
  }
  
  /// The distance between the opposite corners of the box.
  inline double getSize () const {
    return (Vector3D (minMax[0], minMax[1], minMax[2]) - 
	    Vector3D (minMax[3], minMax[4], minMax[5])).getLength ();
  } 
  
private :

  std::vector<double> minMax; ///< a <code>vector</code> is expected by the polygonizer
};

#endif // BBOXMINMAX_H
