#ifndef COLORCOTEXTREE_H
#define COLORCOTEXTREE_H

#include "../Interfaces/CoTeXTreeInterface.h"
#include "../Attributes/ColorAttribute.h"

/// The default base color for ColorCoTeXTrees.
static const ColorAttribute DEFAULT_COLOR (160, 160, 160);

/// A CoTeXTree for the color of objects.
/**
 * With no primitives, this tree set the color of surfels with it's default color.
 * As CoTeXTreeInterface still implements generic methods, primitives with color 
 * textures aren't the only accepted.
 * HyperFun specifications (from HyperFunable) justifies the existence of this 
 * inherited class.
 */
class ColorCoTeXTree : public CoTeXTreeInterface {
public:
  
  /// The base constructor. When it's empty, the tree provide an uniforme base color.
  ColorCoTeXTree ();

  ColorCoTeXTree (const ColorCoTeXTree &);

  virtual ~ColorCoTeXTree () {}

  ColorCoTeXTree &operator= (const ColorCoTeXTree &);
  
  // **********************
  // Interface HyperFunable
  // **********************
  
  void writeHFString (QTextStream & outStream);
  void writeDefArray (QTextStream & outStream);
  void writeDefBody (QTextStream & outStream);

};

#endif // COLORCOTEXTREE_H
