#ifndef TEXTURECONFIGURATIONWIDGET_H
#define TEXTURECONFIGURATIONWIDGET_H

#include <qlistbox.h>
#include <qpixmap.h>
#include <qpushbutton.h>
#include <qsize.h>
#include <qwidgetstack.h>

#include "ColorConfigurationWidget.h"
#include "PerlinNoiseConfigurationWidget.h"
#include "../src/Interfaces/TextureInterface.h"

/// Class for the widget for the creation of new textures  
class TextureConfigurationWidget : public QWidget {
  
  Q_OBJECT
  
public:

  /// The constructor
  /**
   * @param texMap is the only one obligatory, it is the registration 
   * of all the textures use in the currrent session of PointShop
   */
  TextureConfigurationWidget (TextureInterface::TextureMap * texMap,
			      QWidget * parent = 0, 
			      const char * name = 0, 
			      WFlags f = 0);
  
  /// The destructor
  virtual ~TextureConfigurationWidget () {}

  // ********
  // Services
  // ********
  
  /// Allows to insert a texture in the texturesMap
  void insertTexture (SimpleColorTexture * tex);
  void insertTexture (PerlinNoiseColorTexture * tex);
  
signals:

  void addNewTextureName (QString, QPixmap);

private:

  ColorConfigurationWidget * colorConfigurationWidget; ///< the widget for configuring a 'simple color'
  PerlinNoiseConfigurationWidget * perlinNoiseConfigurationWidget; ///< the widget for configuring
                                                                   ///  a 'perlin noise' texture
  QListBox * texturesListBox;
  QWidgetStack * texturesConfigurationWidgetStack;
  TextureInterface::TextureMap * texturesMap;
  
  /// Map for quering AbstractConfigurationWidget with their id.
  typedef QMap<int,AbstractConfigurationWidget*> AbstractConfigurationWidgetMap;
  AbstractConfigurationWidgetMap configurationWidgetMap;
    
  /// Inserts a new texture name in texturesListBox
  void insertInTexturesList (QPixmap pix, const QString & nameTexture, const int textureId);
  
  /// Resizes a widget to the given size
  void resizeWidget (QWidget *, QSize);
  
  /// Add a texture in the current textureMap and update UI
  void  addTexture (TextureInterface * tex, QPixmap pix);
  
  /// Creates a pushButton at the given size and with the given parent
  QPushButton * createPushButton (QString label, QWidget * parent, QSize size);

private slots:

  void aboutTexture (int index);
  void okSlot ();
};
#endif
